@@ -12,7 +12,7 @@ Readonly::Hash my %LANG => (
 	'title' => 'Page title',
 );
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -42,7 +42,7 @@ sub new {
 	}
 
 	# Check to 'CSS::Struct' object.
-	if (! $self->{'css'} || ! $self->{'css'}->isa('CSS::Struct::Output')) {
+	if ($self->{'css'} && ! $self->{'css'}->isa('CSS::Struct::Output')) {
 		err "Parameter 'css' must be a 'CSS::Struct::Output::*' class.";
 	}
 
@@ -66,7 +66,6 @@ sub process {
 		['a', 'http-equiv', 'Content-Type'],
 		['a', 'content', 'text/html; charset=UTF-8'],
 		['e', 'meta'],
-		# XXX Refresh?
 		['b', 'title'],
 		['d', $self->{'lang'}->{'title'}],
 		['e', 'title'],
@@ -85,28 +84,6 @@ sub process {
 	return;
 }
 
-sub process_css {
-	my $self = shift;
-
-	# Create styles.
-	$self->{'css'}->put(
-		['s', '.okay'],
-		['d', 'background', '#9f9'],
-		['e'],
-		['s', '.warning'],
-		['d', 'background', '#ff9'],
-		['e'],
-		['s', '.alert'],
-		['d', 'background', '#f99'],
-		['e'],
-		['s', '.offline'],
-		['d', 'color', '#999'],
-		['e'],
-	);
-
-	return;
-}
-
 1;
 
 __END__
@@ -125,7 +102,6 @@ Tags::HTML::Page::Begin - Tags helper for HTML page begin.
 
  my $obj = Tags::HTML::Page::Begin->new(%params);
  $obj->process;
- $obj->process_css;
 
 =head1 METHODS
 
@@ -177,15 +153,6 @@ Process Tags structure for output.
 
 Returns undef.
 
-=head2 C<process_css>
-
- $obj->process_css;
-
-Process CSS::Struct structure for output.
-This processing must be before L<process>, because in L<process> is output used.
-
-Returns undef.
-
 =head1 ERRORS
 
  new():
@@ -207,6 +174,7 @@ Returns undef.
  # Object.
  my $tags = Tags::Output::Indent->new(
          'preserved' => ['style'],
+         'xml' => 1,
  );
  my $css = CSS::Struct::Output::Indent->new;
  my $begin = Tags::HTML::Page::Begin->new(
@@ -218,7 +186,12 @@ Returns undef.
  );
 
  # Process page
- $begin->process_css;
+ $css->put(
+        ['s', 'div'],
+	['d', 'color', 'red'],
+	['d', 'background-color', 'black'],
+	['e'],
+ );
  $begin->process;
  $tags->put(
         ['b', 'div'],
@@ -234,23 +207,14 @@ Returns undef.
  # <!DOCTYPE html>
  # <html>
  #   <head>
- #     <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
- #     </meta>
+ #     <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
  #     <title>
  #       Page title
  #     </title>
  #     <style type="text/css">
- # .okay {
- # 	background: #9f9;
- # }
- # .warning {
- # 	background: #ff9;
- # }
- # .alert {
- # 	background: #f99;
- # }
- # .offline {
- # 	color: #999;
+ # div {
+ # 	color: red;
+ # 	background-color: black;
  # }
  # </style>
  #   </head>
@@ -295,6 +259,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
